/* osgVisual test. distortionNG, experimental.
*
*  Permission is hereby granted, free of charge, to any person obtaining a copy
*  of this software and associated documentation files (the "Software"), to deal
*  in the Software without restriction, including without limitation the rights
*  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
*  copies of the Software, and to permit persons to whom the Software is
*  furnished to do so, subject to the following conditions:
*
*  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
*  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
*  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
*  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
*  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
*  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
*  THE SOFTWARE.
*/

#pragma once

#include "DistortionSetupStrategy.h"


/**
 * \brief "Project Syntropy" Setup Strategy reads setup files of http://www.project-syntropy.de/ and configures the distortion accordingly.
 * 
 * @author Torben Dannhauer
 * @date  Jun 2012
 */ 
class DistortionSetupStrategyProjectSyntropy :
	public DistortionSetupStrategy
{
public:
	DistortionSetupStrategyProjectSyntropy();
	~DistortionSetupStrategyProjectSyntropy();
	void delegateDistortionSetup(osgViewer::DistortionSet* distortionSet);
	void setDistortionInputFiles( std::string distortionFile, std::string blendmapFile, std::string frustumFile, DistortionSetupStrategy::distortionType type);
private:
	//Functions related to CSV-File-Reading
	int readFrustumFromCSVFile(std::string filePath, int numValues, float* frustumValues);
	int readMeshDimensionsFromCSVFile(std::string filePath, int* meshRows, int* meshColumns);
	int readMeshPointsFromCSVFile(std::string filePath, osg::Vec2Array* meshPointsVec2, osg::Vec3Array* meshPointsVec3);
	int readMeshPointsFromCSVFile(std::string filePath, osg::Vec2Array* meshPointsVec2, osg::Vec3Array* meshPointsVec3, int displayWidth, int displayHeight);

	bool _distortionInitialized;				//Is Distortion already initialized?
	bool _switchDistortionTypeVortexToTexcoords;		//Indicates if Texcoord- (true) or Vortexdistortion (false) is selected

	//Paths of Blending/Warping related Files
	std::string _intensityMapFilename;

	std::string _frustumVortexDistortionFilename;
	std::string _frustumTexcoordDistortionFilename;

	std::string _meshVortexDistortionFilename;
	std::string _meshTexcoordDistortionFilename;
};
